<?php
namespace Teknisa\MYM\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class Mym00112UsuariosQrCodeController extends \Teknisa\GER\Controllers\TeknisaCrud {
    protected $connection;
    protected $dataSourceManager;
    protected $environment;
    
    public function __construct($crudService, $parameterBag, $connection, $dataSourceManager, $environment){
        parent::__construct($crudService, $parameterBag);
        $this->connection        = $connection;
        $this->dataSourceManager = $dataSourceManager;
        $this->environment       = $environment;
    }
    
    public function find($request, $response) {
        $conditions = $request->getFilterCriteria()->getConditions();
        $nrlista = "";
        foreach($conditions as $key => &$condition) {
            if($condition['columnName'] == 'CDFILIAL' && $condition['value'] != 'T') {
                $nrlista = $this->criarListaValores($condition['value']);
                $condition['value'] = $nrlista;
            }
            if($condition['columnName'] == 'NMFILIAL') {
                unset($conditions[$key]);
            }
        }
        array_push($conditions, array(
                "columnName"=> "CDOPERADOR",
                "value"=> $this->environment->getCdOperador(),
                "operator"=> "=",
            )
        );
        $dataSourceName = 'qrcodeusers';
        
        $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
        $response->addDataSet(new DataSet('qrcodeusers',$result));
        $this->apagarListaValores($nrlista);
    }
    
    public function atualizaUsuario($request, $response) {
        $row = $request->getRow();
        $this->connection->beginTransaction();
        try {
            $queryUsuario = "UPDATE USUARIOAPP SET DSPRIMEIRONOME = :DSPRIMEIRONOME, DSULTIMONOME = :DSULTIMONOME WHERE NRUSUARIOAPP = :NRUSUARIOAPP AND NRORG = :NRORG";
            $queryParams = [
                "NRORG"        => $row["NRORG"],
                "DSPRIMEIRONOME" => $row["DSPRIMEIRONOME"],
                "DSULTIMONOME"   => $row["DSULTIMONOME"],
                "NRUSUARIOAPP"   => $row["NRUSUARIOAPP"]
    		];
    		
    		$statementQuery = $this->connection->prepare($queryUsuario);
    		$statementQuery->execute($queryParams);
    		
            $queryIdAtivo = "UPDATE APP_USUARIOAPLICATIVO SET IDATIVO = :IDATIVO WHERE NRUSUARIOAPLICATIVO = :NRUSUARIOAPLICATIVO AND NRORG = :NRORG";
            $queryParams = [
                "NRORG"             => $row["NRORG"],
                "IDATIVO"             => $row["IDATIVO"],
                "NRUSUARIOAPLICATIVO" => $row["NRUSUARIOAPLICATIVO"]
    		];
    		
    		$statementQuery = $this->connection->prepare($queryIdAtivo);
    		$statementQuery->execute($queryParams);
            
            $this->connection->commit();
        } catch(\Exception $e) {
            $this->connection->rollBack();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    //insere lista no banco
    private function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista,
            "NRORG" => $this->environment->getNrorgTrab()
        );
        
        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA, NRORG) VALUES (:NRLISTA, :CDLISTA, :NRORG)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    //apaga lista do banco
    private function deleteLista($nrlista) {
        $params = array(
            "NRLISTA" => $nrlista
        );
        
        $sql = "DELETE FROM LISTA WHERE NRLISTA =:NRLISTA";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    //cria lista de valores recebendo string como parametro
    private function criarListaValores($valores){
        if(strlen($valores) <= 4000){
            return $valores;
        }else{
            $lista = explode('_',$valores);
            $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrorgTrab(), 1, 10, false);
            try{
                foreach($lista as $key){
                    $this->insertLista($nrlista, $key);
                }
                return "_NRLISTA=".$nrlista;
            } catch(\Exception $e){
                throw $e;
            }
        }
    }
    
    //apaga lista de valores recebendo string como parametro
    private function apagarListaValores($valores){
        try{
            if(substr($valores, 0,9) == "_NRLISTA="){
                $nrlista = substr($valores, 9);
                $this->deleteLista($nrlista);
            }
        } catch(\Exception $e){
            throw $e;
        }
    }
}